Index: /trunk/source/visualization/OpenGL/GNUmakefile
===================================================================
--- /trunk/source/visualization/OpenGL/GNUmakefile	(revision 915)
+++ /trunk/source/visualization/OpenGL/GNUmakefile	(revision 916)
@@ -21,4 +21,5 @@
 include $(G4INSTALL)/config/interactivity.gmk
 
+CPPFLAGS += -DG4DEBUG_VIS_OGL
 CPPFLAGS += -I$(G4BASE)/visualization/management/include
 CPPFLAGS += -I$(G4BASE)/visualization/modeling/include
Index: /trunk/source/visualization/OpenGL/include/G4OpenGLQtViewer.hh
===================================================================
--- /trunk/source/visualization/OpenGL/include/G4OpenGLQtViewer.hh	(revision 915)
+++ /trunk/source/visualization/OpenGL/include/G4OpenGLQtViewer.hh	(revision 916)
@@ -144,7 +144,6 @@
   void createRadioAction(QAction *,QAction *, const std::string&,unsigned int a=1);
   void rescaleImage(int, int);
-  bool generateEPS2(QString,int,QImage);  
-  bool generateVectorEPS (QString,int,int,QImage);
-  bool generatePS_PDF(QString,int,QImage);  
+  bool generateVectorEPS (const char *,int,int,QImage);
+  bool generatePS_PDF(const std::string,int,QImage);  
   void showMovieParametersDialog();
   void initMovieParameters();
Index: /trunk/source/visualization/OpenGL/include/G4OpenGLViewer.hh
===================================================================
--- /trunk/source/visualization/OpenGL/include/G4OpenGLViewer.hh	(revision 915)
+++ /trunk/source/visualization/OpenGL/include/G4OpenGLViewer.hh	(revision 916)
@@ -85,8 +85,7 @@
   GLdouble getSceneFarWidth();
   GLdouble getSceneDepth();
-  G4float                           pointSize;
-  char                              print_string[50];
-  G4bool                            print_colour;
-  G4bool                            vectored_ps;
+  std::string                       fPrintFilename;
+  G4bool                            fPrintColour;
+  G4bool                            fVectoredPs;
 
   G4OpenGLSceneHandler& fOpenGLSceneHandler;
@@ -108,4 +107,7 @@
     fDisplayLightFrontT;
   G4double fDisplayLightFrontRed, fDisplayLightFrontGreen, fDisplayLightFrontBlue;
+
+private :
+  G4float                           fPointSize;
 };
 
Index: /trunk/source/visualization/OpenGL/src/G4OpenGLQtViewer.cc
===================================================================
--- /trunk/source/visualization/OpenGL/src/G4OpenGLQtViewer.cc	(revision 915)
+++ /trunk/source/visualization/OpenGL/src/G4OpenGLQtViewer.cc	(revision 916)
@@ -1293,26 +1293,26 @@
   QString* selectedFormat = new QString();
 #if QT_VERSION < 0x040000
-  QString nomFich =  QFileDialog::getSaveFileName ( ".",
+  fPrintFilename =  QFileDialog::getSaveFileName ( ".",
                                                     filters,
                                                     GLWindow,
                                                     "Save file dialog",
                                                     tr("Save as ..."),
-                                                    selectedFormat ); 
-#else
-  QString nomFich =  QFileDialog::getSaveFileName ( GLWindow,
+                                                    selectedFormat ).ascii(); 
+#else
+  fPrintFilename =  QFileDialog::getSaveFileName ( GLWindow,
                                                     tr("Save as ..."),
                                                     ".",
                                                     filters,
-                                                    selectedFormat ); 
+                                                    selectedFormat ).toStdString().c_str(); 
 #endif
   // bmp jpg jpeg png ppm xbm xpm
-  if (nomFich == "") {
+  if (fPrintFilename.empty()) {
     return;
   }
 #if QT_VERSION < 0x040000
-  nomFich += "."+QString(selectedFormat->ascii());
+  fPrintFilename += "." + selectedFormat->ascii();
   QString format = selectedFormat->lower();
 #else
-  nomFich += "."+QString(selectedFormat->toStdString().c_str());
+  fPrintFilename += "." + selectedFormat->toStdString();
   QString format = selectedFormat->toLower();
 #endif
@@ -1348,10 +1348,10 @@
     if (format == QString("eps")) {
       if (exportDialog->getVectorEPS()) {
-        res = generateVectorEPS(nomFich,exportDialog->getWidth(),exportDialog->getHeight(),image);
+        res = generateVectorEPS(fPrintFilename.c_str(),exportDialog->getWidth(),exportDialog->getHeight(),image);
       } else {
-        res = generateEPS2(nomFich,exportDialog->getNbColor(),image);
+        res = generateEPS(fPrintFilename.c_str(),exportDialog->getNbColor(),(unsigned int)image.width(),(unsigned int)image.height());
       }
     } else if ((format == "ps") || (format == "pdf")) {
-      res = generatePS_PDF(nomFich,exportDialog->getNbColor(),image);
+      res = generatePS_PDF(fPrintFilename,exportDialog->getNbColor(),image);
     } else if ((format == "tif") ||
                (format == "tiff") ||
@@ -1366,7 +1366,7 @@
                (format == "xpm")) {
 #if QT_VERSION < 0x040000
-      res = image.save(nomFich,selectedFormat->ascii(),exportDialog->getSliderValue());
-#else
-      res = image.save(nomFich,0,exportDialog->getSliderValue());
+      res = image.save(QString(fPrintFilename.c_str()),selectedFormat->ascii(),exportDialog->getSliderValue());
+#else
+      res = image.save(QString(fPrintFilename.c_str()),0,exportDialog->getSliderValue());
 #endif
     } else {
@@ -1374,15 +1374,7 @@
     }
     if (res == false) {
-#if QT_VERSION < 0x040000
-      G4cerr << "Error while saving file... "<<nomFich.ascii()<<"" << G4endl;
-#else
-      G4cerr << "Error while saving file... "<<nomFich.toStdString().c_str()<< G4endl;
-#endif
+      G4cerr << "Error while saving file... "<<fPrintFilename.c_str()<< G4endl;
     } else {
-#if QT_VERSION < 0x040000
-      G4cout << "File "<<nomFich.ascii()<<" has been saved " << G4endl;
-#else
-      G4cout << "File "<<nomFich.toStdString().c_str()<<" has been saved " << G4endl;
-#endif
+      G4cout << "File "<<fPrintFilename.c_str()<<" has been saved " << G4endl;
     }
     
@@ -1660,5 +1652,5 @@
 */
 bool G4OpenGLQtViewer::generateVectorEPS (
- QString aFilename
+ const char * aFilename
 ,int aWidth
 ,int aHeight
@@ -1684,17 +1676,9 @@
   
   
-#if QT_VERSION < 0x040000
-  file = fopen (aFilename.ascii(), "w");
-#else
-  file = fopen (aFilename.toStdString().c_str(), "w");
-#endif
+  file = fopen (aFilename, "w");
   if (file) {
     spewWireframeEPS (file, returned, feedback_buffer, "rendereps");
   } else {
-#if QT_VERSION < 0x040000
-    G4cerr << "Could not open "<< aFilename.ascii() << G4endl;
-#else
-    G4cerr << "Could not open "<< aFilename.toStdString().c_str() << G4endl;
-#endif
+    G4cerr << "Could not open "<< aFilename << G4endl;
   }
   
@@ -1704,145 +1688,5 @@
 }
 
-/**
-   Generate Encapsulated Postscript form image
-   @param aFilename : name of file
-   @param aInColor : numbers of colors : 1->BW 2->RGB 3->RGB+Alpha
-   @param aImage : Image to print
-*/
-bool G4OpenGLQtViewer::generateEPS2 (
- QString aFilename
-,int aInColor
-,QImage aImage
-)
-{
-#ifdef G4DEBUG_VIS_OGL
-  printf("G4OpenGLQtViewer::generateEPS call parent\n");
-#endif
-  generateEPS((aFilename+"GL").toStdString().c_str(),3,(unsigned int)aImage.width(),(unsigned int)aImage.height());
-#ifdef G4DEBUG_VIS_OGL
-  printf("G4OpenGLQtViewer::generateEPS\n");
-#endif
-  // FIXME
-
-  FILE* fp;
-
-  if (aImage.bits () == NULL)
-    return false;
-  
-#if QT_VERSION < 0x040000
-  fp = fopen (aFilename.ascii(), "w");
-#else
-  fp = fopen (aFilename.toStdString().c_str(), "w");
-#endif
-  if (fp == NULL) {
-    return false;
-  }
-  
-  fprintf (fp, "%%!PS-Adobe-2.0 EPSF-1.2\n");
-#if QT_VERSION < 0x040000
-  fprintf (fp, "%%%%Title: %s\n", aFilename.ascii());
-#else
-  fprintf (fp, "%%%%Title: %s\n", aFilename.toStdString().c_str());
-#endif
-  fprintf (fp, "%%%%Creator: OpenGL pixmap render output\n");
-  fprintf (fp, "%%%%BoundingBox: 0 0 %d %d\n", aImage.width(), aImage.height());
-  fprintf (fp, "%%%%EndComments\n");
-  fprintf (fp, "gsave\n");
-  fprintf (fp, "/bwproc {\n");
-  fprintf (fp, "    rgbproc\n");
-  fprintf (fp, "    dup length 3 idiv string 0 3 0 \n");
-  fprintf (fp, "    5 -1 roll {\n");
-  fprintf (fp, "    add 2 1 roll 1 sub dup 0 eq\n");
-  fprintf (fp, "    { pop 3 idiv 3 -1 roll dup 4 -1 roll dup\n");
-  fprintf (fp, "       3 1 roll 5 -1 roll } put 1 add 3 0 \n");
-  fprintf (fp, "    { 2 1 roll } ifelse\n");
-  fprintf (fp, "    }forall\n");
-  fprintf (fp, "    pop pop pop\n");
-  fprintf (fp, "} def\n");
-  fprintf (fp, "systemdict /colorimage known not {\n");
-  fprintf (fp, "   /colorimage {\n");
-  fprintf (fp, "       pop\n");
-  fprintf (fp, "       pop\n");
-  fprintf (fp, "       /rgbproc exch def\n");
-  fprintf (fp, "       { bwproc } image\n");
-  fprintf (fp, "   }  def\n");
-  fprintf (fp, "} if\n");
-  fprintf (fp, "/picstr %d string def\n", aImage.width() * aInColor);
-  fprintf (fp, "%d %d scale\n", aImage.width(), aImage.height());
-  fprintf (fp, "%d %d %d\n", aImage.width(), aImage.height(), 8);
-  fprintf (fp, "[%d 0 0 %d 0 0]\n", aImage.width(), aImage.height());
-  fprintf (fp, "{currentfile picstr readhexstring pop}\n");
-  fprintf (fp, "false %d\n", aInColor);
-  fprintf (fp, "colorimage\n");
-  
-
-  int width = aImage.width();
-  int height = aImage.height();
-  int depth = aImage.depth();
-  int size = width*height;
-  
-  if (depth == 1)
-    size = (width+7)/8*height;
-  else if (aInColor == 1)
-    size = size*3;
-  
-  int i = 0;
-  //  if ( aInColor ==1 ) {
-  // FIXME : L. Garnier. For the moment 10 dec 2007, I could not find a way
-  // to save correctly grayscale Image. I mean that color or grayscale image
-  // have the same file save size !
-  
-  /* } else*/ if (depth == 8) {
-    for(int y=height-1; y >=0 ; y--) {
-      const uchar * s = aImage.scanLine(y);
-      for(int x=0; x <width; x++) {
-        QRgb rgb = aImage.color(s[x]);
-        if (aInColor == 1) {
-          fprintf (fp, " %02hx ",(unsigned char)qGray(rgb));
-          i++;
-        } else {
-          fprintf (fp, " %02hx %02hx %02hx",
-                   (unsigned char) qRed(rgb),
-                   (unsigned char) qGreen(rgb),
-                   (unsigned char) qBlue(rgb));
-          i += 3;
-        }
-      }
-      fprintf (fp, "\n");
-    }
-  } else {
-#if QT_VERSION < 0x040000
-    bool alpha = aImage.hasAlphaBuffer();
-#else
-    bool alpha = aImage.hasAlphaChannel();
-#endif
-    for(int y=height-1; y >=0 ; y--) {
-      QRgb * s = (QRgb*)(aImage.scanLine(y));
-      for(int x=0; x <width; x++) {
-        QRgb rgb = (*s++);
-        if (alpha && qAlpha(rgb) < 0x40) // 25% alpha, convert to white -
-          rgb = qRgb(0xff, 0xff, 0xff);
-        if (aInColor == 1) {
-          fprintf (fp, " %02hx ",(unsigned char)qGray(rgb));
-          i++;
-        } else {
-          fprintf (fp, " %02hx %02hx %02hx",
-                   (unsigned char) qRed(rgb),
-                   (unsigned char) qGreen(rgb),
-                   (unsigned char) qBlue(rgb));
-          i += 3;
-        }
-      }
-      fprintf (fp, "\n");
-    } 
-
-  }
-
-  fprintf (fp, "grestore\n");
-  fprintf (fp, "showpage\n");
-  fclose (fp);
-
-  return true;
-}
+
 /**
    Generate Postscript or PDF form image
@@ -1852,5 +1696,5 @@
 */
 bool G4OpenGLQtViewer::generatePS_PDF (
- QString aFilename
+ const std::string aFilename
 ,int aInColor
 ,QImage aImage
@@ -1899,5 +1743,5 @@
 
 
-  if (aFilename.endsWith(".ps")) {
+  if (aFilename.substr(aFilename.size()-3) == ".ps") {
 #if QT_VERSION > 0x040200
     printer.setOutputFormat(QPrinter::PostScriptFormat);
@@ -1909,5 +1753,5 @@
   }
 #if QT_VERSION > 0x040100
-  printer.setOutputFileName(aFilename);
+  printer.setOutputFileName(QString(aFilename.c_str()));
 #endif
   //  printer.setFullPage ( true);
Index: /trunk/source/visualization/OpenGL/src/G4OpenGLViewer.cc
===================================================================
--- /trunk/source/visualization/OpenGL/src/G4OpenGLViewer.cc	(revision 915)
+++ /trunk/source/visualization/OpenGL/src/G4OpenGLViewer.cc	(revision 916)
@@ -82,7 +82,7 @@
 G4OpenGLViewer::G4OpenGLViewer (G4OpenGLSceneHandler& scene):
 G4VViewer (scene, -1),
-pointSize (0),
-print_colour (true),
-vectored_ps (true),
+fPrintFilename ("G4OpenGL.eps"),
+fPrintColour (true),
+fVectoredPs (true),
 fOpenGLSceneHandler(scene),
 background (G4Colour(0.,0.,0.)),
@@ -107,5 +107,6 @@
 fDisplayLightFrontRed(0.),
 fDisplayLightFrontGreen(1.),
-fDisplayLightFrontBlue(0.)
+fDisplayLightFrontBlue(0.),
+fPointSize (0)
 {
   // Make changes to view parameters for OpenGL...
@@ -121,5 +122,4 @@
   //  glDisable (GL_POLYGON_SMOOTH);
 
-  strcpy (print_string, "G4OpenGL.eps");
 }
 
@@ -405,10 +405,10 @@
   
   FILE* file;
-  if (print_string) {
-    file = fopen (print_string, "w");
+  if (!fPrintFilename.empty()) {
+    file = fopen (fPrintFilename.c_str(), "w");
     if (file) {
       spewWireframeEPS (file, returned, feedback_buffer, "rendereps");
     } else {
-      printf("Could not open %s\n", print_string);
+      printf("Could not open %s\n", fPrintFilename.c_str());
     }
   } else {
@@ -442,5 +442,5 @@
   glGetFloatv (GL_COLOR_CLEAR_VALUE, clearColor);
   glGetFloatv (GL_LINE_WIDTH, &lineWidth);
-  glGetFloatv (GL_POINT_SIZE, &pointSize);
+  glGetFloatv (GL_POINT_SIZE, &fPointSize);
 
   fputs ("%!PS-Adobe-2.0 EPSF-2.0\n", file);
@@ -539,5 +539,5 @@
     db=vertex[1].blue - vertex[0].blue;
 
-    if (!print_colour) {
+    if (!fPrintColour) {
       dr+=(dg+db);
       dr/=3.0;
@@ -575,5 +575,5 @@
       bnext=vertex[0].blue;
 
-      if (!print_colour) {
+      if (!fPrintColour) {
 	rnext+=(gnext+bnext);
 	rnext/=3.0;
@@ -590,5 +590,5 @@
       steps=0;
     }
-    if (print_colour) {
+    if (fPrintColour) {
       fprintf (file, "%g %g %g setrgbcolor\n",
 	       vertex[0].red, vertex[0].green, vertex[0].blue);
@@ -627,5 +627,5 @@
       smooth=0;
       
-      if (!print_colour) {
+      if (!fPrintColour) {
 	red+=(green+blue);
 	red/=3.0;
@@ -634,5 +634,5 @@
       }
       
-      if (print_colour) {
+      if (fPrintColour) {
 	for (i=1; i<nvertices; i++) {
 	  if (red!=vertex[i].red || green!=vertex[i].green || blue!=vertex[i].blue) {
@@ -659,5 +659,5 @@
 		   vertex[0].x, vertex[i+1].x, vertex[i+2].x,
 		   vertex[0].y, vertex[i+1].y, vertex[i+2].y);
-	  if (print_colour) {
+	  if (fPrintColour) {
 	    fprintf (file, " [%g %g %g] [%g %g %g] [%g %g %g] gouraudtriangle\n",
 		     vertex[0].red, vertex[0].green, vertex[0].blue,
@@ -694,5 +694,5 @@
   case GL_POINT_TOKEN:
     vertex=(Feedback3Dcolor*)loc;
-    if (print_colour) {
+    if (fPrintColour) {
       fprintf (file, "%g %g %g setrgbcolor\n", vertex[0].red, vertex[0].green, vertex[0].blue);
     } else {
@@ -701,5 +701,5 @@
       fprintf (file, "%g %g %g setrgbcolor\n", intensity, intensity, intensity);
     }      
-    fprintf(file, "%g %g %g 0 360 arc fill\n\n", vertex[0].x, vertex[0].y, pointSize / 2.0);
+    fprintf(file, "%g %g %g 0 360 arc fill\n\n", vertex[0].x, vertex[0].y, fPointSize / 2.0);
     loc += 7;           /* Each vertex element in the feedback
                            buffer is 7 GLfloats. */
Index: /trunk/source/visualization/OpenGL/src/G4OpenGLXViewer.cc
===================================================================
--- /trunk/source/visualization/OpenGL/src/G4OpenGLXViewer.cc	(revision 915)
+++ /trunk/source/visualization/OpenGL/src/G4OpenGLXViewer.cc	(revision 916)
@@ -413,7 +413,7 @@
   
   //using namespace std;
-  //cout << "print_col_callback requested with file name: " << print_string << G4endl;
-  
-  if (vectored_ps) {
+  //cout << "print_col_callback requested with file name: " << fPrintFilename << G4endl;
+  
+  if (fVectoredPs) {
 
     G4OpenGLViewer::print();
@@ -454,6 +454,6 @@
     DrawView ();
     
-    generateEPS (print_string,
-		 print_colour,
+    generateEPS (fPrintFilename.c_str(),
+		 fPrintColour,
 		 fWinSize_x, fWinSize_y);
     
Index: /trunk/source/visualization/OpenGL/src/G4OpenGLXmMainMenubarCallbacks.cc
===================================================================
--- /trunk/source/visualization/OpenGL/src/G4OpenGLXmMainMenubarCallbacks.cc	(revision 915)
+++ /trunk/source/visualization/OpenGL/src/G4OpenGLXmMainMenubarCallbacks.cc	(revision 916)
@@ -452,10 +452,10 @@
 	pView->fpprint_col_radio1 = new G4OpenGLXmRadioButton ("Black and white",
 							       prcol_cb_list,
-							       pView->print_colour==false ? True : False,
+							       pView->fPrintColour==false ? True : False,
 							       0);
 	
 	pView->fpprint_col_radio2 = new G4OpenGLXmRadioButton ("Colour",
 							       prcol_cb_list,
-							       pView->print_colour==true ? True : False,
+							       pView->fPrintColour==true ? True : False,
 							       1);
 	
@@ -474,10 +474,10 @@
 	pView->fpprint_style_radio1 = new G4OpenGLXmRadioButton ("Screen dump (pixmap)",
 								 prsty_cb_list,
-								 pView->vectored_ps==false ? True : False,
+								 pView->fVectoredPs==false ? True : False,
 								 0);
 	
 	pView->fpprint_style_radio2 = new G4OpenGLXmRadioButton ("PostScript",
 								 prsty_cb_list,
-								 pView->vectored_ps==true ? True : False,
+								 pView->fVectoredPs==true ? True : False,
 								 1);
 	
@@ -486,5 +486,5 @@
 	
 	pView->fpprint_text = new G4OpenGLXmTextField ("Name of .eps file to save",
-						       (pView->print_string));
+						       (pView->fPrintFilename.c_str()));
 	pView->fpprint_box->AddChild (pView->fpprint_text);	
 	
Index: /trunk/source/visualization/OpenGL/src/G4OpenGLXmWindowHandlingCallbacks.cc
===================================================================
--- /trunk/source/visualization/OpenGL/src/G4OpenGLXmWindowHandlingCallbacks.cc	(revision 915)
+++ /trunk/source/visualization/OpenGL/src/G4OpenGLXmWindowHandlingCallbacks.cc	(revision 916)
@@ -85,6 +85,6 @@
   G4int choice = get_int_userData (w);
   
-  pView->print_colour=(G4bool)choice;
-  G4cout << "Print colour set to " << pView->print_colour;
+  pView->fPrintColour=(G4bool)choice;
+  G4cout << "Print colour set to " << pView->fPrintColour;
   
 }
@@ -98,6 +98,6 @@
   G4int choice = get_int_userData (w);
   
-  pView->vectored_ps=(G4bool)choice;
-  G4cout << "`Produce vectored PostScript ?' set to : " << pView->print_colour;
+  pView->fVectoredPs=(G4bool)choice;
+  G4cout << "`Produce vectored PostScript ?' set to : " << pView->fPrintColour;
   
 }
Index: /trunk/source/visualization/modeling/History
===================================================================
--- /trunk/source/visualization/modeling/History	(revision 915)
+++ /trunk/source/visualization/modeling/History	(revision 916)
@@ -1,3 +1,3 @@
-$Id: History,v 1.105 2008/07/27 10:49:24 allison Exp $
+$Id: History,v 1.106 2008/11/21 21:50:02 perl Exp $
 -------------------------------------------------------------------
 
@@ -21,5 +21,5 @@
 ---------------------------------------
 
-27th July 2008  John Allison
+27th July 2008  John Allison (modeling-V09-01-01)
 - G4PhysicalVolumeSearchScene.cc: Cosmetic improvement to a message.
 

Index: /trunk/source/visualization/OpenGL/src/G4OpenGLViewerMessenger.cc
===================================================================
--- /trunk/source/visualization/OpenGL/src/G4OpenGLViewerMessenger.cc	(revision 915)
+++ /trunk/source/visualization/OpenGL/src/G4OpenGLViewerMessenger.cc	(revision 916)
@@ -252,17 +252,16 @@
   if (command == fpCommandPrintEPS) 
     {
-      // Keep copy of print_string to preserve Xm behaviour...
-      char* tmp_string = new char[50];
-      strcpy (tmp_string, pOGLViewer->print_string);
+      // Keep copy of fPrintFilename to preserve Xm behaviour...
+      std::string tmp_string = pOGLViewer->fPrintFilename;
+
       // Make new print string...
       static G4int file_count = 0;
       std::ostringstream oss;
       oss << "G4OpenGL_" << file_count++ << ".eps";
-      strcpy (pOGLViewer->print_string, oss.str().c_str());
+      pOGLViewer->fPrintFilename = std::string(oss.str().c_str());
       // Print eps file...
       pOGLViewer->print();
-      // Restore print_string for Xm...
-      strcpy (pOGLViewer->print_string, tmp_string);
-      delete tmp_string;
+      // Restore fPrintFilename for Xm...
+      pOGLViewer->fPrintFilename = tmp_string;
       return;
     }
@@ -346,7 +345,7 @@
   if (command == fpCommandPrintMode)
     {
-      if (newValue == "vectored") pViewer->vectored_ps = true;
+      if (newValue == "vectored") pViewer->fVectoredPs = true;
       if (newValue == "pixmap") {
-	pViewer->vectored_ps = false;
+	pViewer->fVectoredPs = false;
 	if (pVisManager->GetVerbosity() >= G4VisManager::warnings) {
 	  G4cout <<
Index: /trunk/source/visualization/OpenGL/src/G4OpenGLXViewerMessenger.cc
===================================================================
--- /trunk/source/visualization/OpenGL/src/G4OpenGLXViewerMessenger.cc	(revision 915)
+++ /trunk/source/visualization/OpenGL/src/G4OpenGLXViewerMessenger.cc	(revision 916)
@@ -96,17 +96,16 @@
   if (command == fpCommandPrintEPS)
     {
-      // Keep copy of print_string to preserve Xm behaviour...
-      char* tmp_string = new char[50];
-      strcpy (tmp_string, pViewer->print_string);
+      // Keep copy of fPrintFilename to preserve Xm behaviour...
+      std::string tmp_string = pViewer->fPrintFilename;
+
       // Make new print string...
       static G4int file_count = 0;
       std::ostringstream oss;
       oss << "G4OpenGL_" << file_count++ << ".eps";
-      strcpy (pViewer->print_string, oss.str().c_str());
+      pViewer->fPrintFilename = std::string (oss.str().c_str());
       // Print eps file...
       pViewer->print();
-      // Restore print_string for Xm...
-      strcpy (pViewer->print_string, tmp_string);
-      delete tmp_string;
+      // Restore fPrintFilename for Xm...
+      pViewer->fPrintFilename = tmp_string;
     }
 